@@ -4,8 +4,8 @@ $self = {
           'deps' => [
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/gobject-introspection-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -D_REENTRANT -D_REENTRANT -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include ',
-          'libs' => '-lgirepository-1.0 -lgobject-2.0 -lglib-2.0 -lintl -Wl,--export-all-symbols -lgmodule-2.0 -lglib-2.0 -lintl -L/usr/lib/../lib -lffi',
+          'inc' => '-I/usr/include/gobject-introspection-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -pthread -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include ',
+          'libs' => '-lgirepository-1.0 -lgobject-2.0 -lglib-2.0 -lintl -Wl,--export-all-symbols -lgmodule-2.0 -pthread -lglib-2.0 -lintl -L/usr/lib/../lib -lffi',
           'typemaps' => []
         };
 
